@@ -1,8 +1,8 @@
 <?php
 /*
- * $Horde: horde/css.php,v 1.7.2.6 2002/01/02 17:05:05 jan Exp $
+ * $Horde: horde/css.php,v 1.7.2.12 2004/03/26 22:43:21 jan Exp $
  *
- * Copyright 2000-2002 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 2000-2004 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -18,7 +18,7 @@ $registry = &Registry::singleton();
 $browser = new Browser();
 
 // Figure out if we've been inlined, or called directly.
-$send_headers = strstr($HTTP_SERVER_VARS['PHP_SELF'], 'css.php');
+$send_headers = strstr($_SERVER['PHP_SELF'], 'css.php');
 
 // Set initial $mtime of this script.
 $mtime = getlastmod();
@@ -31,7 +31,7 @@ if (@file_exists(HORDE_BASE . '/config/horde.php')) {
 
 
 if (Horde::getFormData('inherit') !== 'no') {
-    if (@file_exists('./config/html.php')) {
+    if (@file_exists(HORDE_BASE . '/config/html.php')) {
         if ($conf['css']['cached']) {
             $hmtime = filemtime(HORDE_BASE . '/config/html.php');
             if ($hmtime > $mtime) {
@@ -73,7 +73,7 @@ if ($send_headers) {
         header('Pragma: no-cache');
         header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
     }
-    header('Content-type: text/css');
+    header('Content-Type: text/css; charset=iso-8859-1');
 }
 
 if (is_array($css)) {
@@ -87,5 +87,3 @@ if (is_array($css)) {
         echo '} ';
     }
 }
-
-?>
