@@ -1,25 +1,28 @@
 <?php
 /*
- * $Horde: horde/index.php,v 2.43.2.6 2002/03/10 00:39:39 chuck Exp $
+ * $Horde: horde/index.php,v 2.43.2.10 2004/03/26 22:43:21 jan Exp $
  *
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
 define('HORDE_BASE', dirname(__FILE__));
-$horde_configured = (@file_exists('./config/horde.php') &&
-                     @file_exists('./config/html.php') &&
-                     @file_exists('./config/mime_drivers.php') &&
-                     @file_exists('./config/mime_mapping.php') &&
-                     @file_exists('./config/registry.php'));
+$horde_configured = (@file_exists(HORDE_BASE . '/config/horde.php') &&
+                     @file_exists(HORDE_BASE . '/config/html.php') &&
+                     @file_exists(HORDE_BASE . '/config/mime_drivers.php') &&
+                     @file_exists(HORDE_BASE . '/config/mime_mapping.php') &&
+                     @file_exists(HORDE_BASE . '/config/registry.php'));
 
 if ($horde_configured) {
     include_once HORDE_BASE . '/lib/base.php';
 
-    if (isset($registry->applications['horde']['initial_page'])) {
+    $initial_app = $prefs->getValue('initial_application');
+    if (!empty($initial_app)) {
+        $main_page = Horde::url($registry->getInitialPage($initial_app));
+    } elseif (isset($registry->applications['horde']['initial_page'])) {
         $main_page = Horde::applicationUrl($registry->applications['horde']['initial_page']);
     } else {
         $main_page = Horde::applicationUrl('login.php');
