@@ -1,9 +1,22 @@
 <?php
-// $Horde: horde/lib/Registry.php,v 1.59.2.12 2002/04/14 16:38:40 jan Exp $
+/*
+ * $Horde: horde/lib/Registry.php,v 1.59.2.25 2003/08/18 15:57:26 jan Exp $
+ *
+ * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Jon Parise <jon@horde.org>
+ * Copyright 1999-2003 Anil Madhavapeddy <anil@recoil.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 require_once 'PEAR.php';
 require_once dirname(__FILE__) . '/Horde.php';
 
+/* Turn PHP stuff off that can really screw things up. */
+ini_set('magic_quotes_sybase', 0);
+ini_set('magic_quotes_runtime', 0);
+
 /**
  * The Registry:: class provides a set of methods for communication
  * between Horde applications and keeping track of application
@@ -12,7 +25,7 @@ require_once dirname(__FILE__) . '/Horde.php';
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.59.2.12 $
+ * @version $Revision: 1.59.2.25 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -109,6 +122,13 @@ class Registry {
 
         /* Set other common defaults like templates and graphics */
         foreach (array_keys($this->applications) as $appName) {
+            // Simply discard applications marked as inactive.
+            if (array_key_exists('active', $this->applications[$appName]) &&
+                !$this->applications[$appName]['active']) {
+                unset($this->applications[$appName]);
+                continue;
+            }
+
             $app = &$this->applications[$appName];
             if (!isset($app['templates'])) {
                 $app['templates'] = $app['fileroot'] . '/templates';
@@ -117,7 +137,32 @@ class Registry {
                 $app['graphics'] = $app['webroot'] . '/graphics';
             }
         }
+    }
 
+    /**
+     * Return a list of the installed and registered applications.  If
+     * no applications are defined return a null array.
+     *
+     * @param array $filter  (optional) An array of the statuses that
+     *                       should be returned. Defaults to non-hidden.
+     *
+     * @return array List of apps registered with Horde
+     *
+     * @since Horde 2.2
+     */
+    function listApps($filter = null)
+    {
+        $apps = array();
+        if (is_null($filter)) {
+            $filter = array('notoolbar', 'active');
+        }
+        foreach ($this->applications as $app => $params) {
+            if (in_array($params['status'], $filter)) {
+                $apps[] = $app;
+            }
+        }
+
+        return $apps;
     }
 
     /**
@@ -229,7 +274,7 @@ class Registry {
         // including any files which might do it for us.
         $pushed = $this->pushApp($package);
 
-        @include_once $file;
+        include_once $file;
         if (!function_exists($function)) {
             return PEAR::raiseError('The function implementing ' . $method . ' (' . $function . ') is not defined in ' . $file . '.');
         }
@@ -265,9 +310,9 @@ class Registry {
      *
      * @param string $method        The method to link to.
      * @param optional array $args  Arguments to the method.
-     * @param optional array $extra Extra, non-standard arguments to the method.
+     * @param optional mixed $extra Extra, non-standard arguments to the method.
      */
-    function link($method, $args = array(), $extra = array())
+    function link($method, $args = array(), $extra = '')
     {
         if (!$this->hasMethod($method)) {
             // no link defined
@@ -283,9 +328,9 @@ class Registry {
      *
      * @param string $method        The method to link to.
      * @param optional array $args  Arguments to the method.
-     * @param optional array $extra Extra, non-standard arguments to the method.
+     * @param optional mixed $extra Extra, non-standard arguments to the method.
      */
-    function plink($method, $args = array(), $extra = array())
+    function plink($method, $args = array(), $extra = '')
     {
         echo $this->link($method, $args, $extra);
     }
@@ -296,9 +341,9 @@ class Registry {
      * @param string $package the desired package.
      * @param string $method        The method to link to.
      * @param optional array $args  Arguments to the method.
-     * @param optional array $extra Extra, non-standard arguments to the method.
+     * @param optional mixed $extra Extra, non-standard arguments to the method.
      */
-    function linkByPackage($package, $method, $args = array(), $extra = array())
+    function linkByPackage($package, $method, $args = array(), $extra = '')
     {
         list($type, $subtype) = explode('/', $method);
         if (empty($this->services[$package][$type][$subtype]['link'])) {
@@ -327,15 +372,19 @@ class Registry {
 
         // fill in urlencoded arguments
         foreach ($args as $key => $val) {
-            $link = str_replace('|' . $key . '|', urlencode($val), $link);
+            $link = str_replace('|' . strtolower($key) . '|', urlencode($val), $link);
         }
 
         // append any extra, non-standard arguments
-        $extra_args = '';
-        foreach ($extra as $key => $val) {
-            $key = urlencode($key);
-            $val = urlencode($val);
-            $extra_args .= "&$key=$val";
+        if (is_array($extra)) {
+            $extra_args = '';
+            foreach ($extra as $key => $val) {
+                $key = urlencode($key);
+                $val = urlencode($val);
+                $extra_args .= "&$key=$val";
+            }
+        } else {
+            $extra_args = $extra;
         }
         $link = str_replace('|extra|', $extra_args, $link);
 
@@ -353,9 +402,9 @@ class Registry {
      * @param string $package the desired package.
      * @param string $method        The method to link to.
      * @param optional array $args  Arguments to the method.
-     * @param optional array $extra Extra, non-standard arguments to the method.
+     * @param optional mixed $extra Extra, non-standard arguments to the method.
      */
-    function plinkByPackage($package, $method, $args = array(), $extra = array())
+    function plinkByPackage($package, $method, $args = array(), $extra = '')
     {
         echo $this->linkByPackage($package, $method, $args, $extra);
     }
@@ -374,7 +423,7 @@ class Registry {
                 list($type, $subtype) = explode('/', $key);
                 $application = $this->registry[$type][$subtype];
                 if (!empty($this->services[$application][$type][$subtype]['includeFile'])) {
-                    @include_once $this->applicationFilePath($this->services[$application][$type][$subtype]['includeFile'], $application);
+                    include_once $this->applicationFilePath($this->services[$application][$type][$subtype]['includeFile'], $application);
                 }
             }
         }
@@ -391,7 +440,7 @@ class Registry {
     {
         list($type, $subtype) = explode('/', $method);
         if (!empty($this->services[$application][$type][$subtype]['includeFile'])) {
-            @include_once $this->applicationFilePath($this->services[$application][$type][$subtype]['includeFile'], $application);
+            include_once $this->applicationFilePath($this->services[$application][$type][$subtype]['includeFile'], $application);
         }
     }
 
@@ -448,8 +497,7 @@ class Registry {
                be loaded. */
             if (!isset($session_started)) {
                 $session_started = true;
-                session_set_cookie_params(0, $this->getParam('cookie_path'), $this->getParam('cookie_domain'));
-                session_name(urlencode($GLOBALS['conf']['session_name']));
+                Horde::setupSessionHandler();
                 @session_start();
             }
 
@@ -537,7 +585,19 @@ class Registry {
         if (!isset($this->confCache[$app])) {
             if (!isset($this->confCache['horde'])) {
                 $conf = array();
-                @include HORDE_BASE . '/config/horde.php';
+                include HORDE_BASE . '/config/horde.php';
+
+                // Initial Horde-wide settings
+                // Set the error reporting level in accordance with the config settings.
+                error_reporting($conf['debug_level']);
+
+                // Set the maximum execution time in accordance with the config settings.
+                @set_time_limit($conf['max_exec_time']);
+
+                // set the umask according to config settings
+                if (isset($conf['umask'])) {
+                    umask($conf['umask']);
+                }
             } else {
                 $conf = $this->confCache['horde'];
             }
@@ -562,8 +622,8 @@ class Registry {
     {
         /* If there is no logged in user, return an empty Prefs::
          * object with just default preferences. */
-        @include_once HORDE_BASE . '/lib/Auth.php';
-        @include_once HORDE_BASE . '/lib/Prefs.php';
+        include_once HORDE_BASE . '/lib/Auth.php';
+        include_once HORDE_BASE . '/lib/Prefs.php';
 
         if (!isset($app)) {
             $app = $this->getApp();
@@ -711,6 +771,9 @@ class Registry {
      *
      * @return string The character set that should be used with the
      * current locale settings.
+     *
+     * @deprecated since Horde 2.1
+     * @see Lang::getCharset()
      */
     function getCharset()
     {
