@@ -1,10 +1,10 @@
 <?php
 /*
-* $Horde: horde/maintenance.php,v 1.3.2.5 2002/04/14 15:23:50 jan Exp $
+* $Horde: horde/maintenance.php,v 1.3.2.8 2004/03/26 22:43:21 jan Exp $
 *
-* Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
-* Copyright 1999-2002 Jon Parise <jon@horde.org>
-* Copyright 2001-2002 Michael Slusarz <slusarz@bigworm.colorado.edu>
+* Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+* Copyright 1999-2004 Jon Parise <jon@horde.org>
+* Copyright 2001-2004 Michael Slusarz <slusarz@bigworm.colorado.edu>
 *
 * See the enclosed file COPYING for license information (LGPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -26,9 +26,7 @@ if (!$module) {
     Horde::fatal(new PEAR_Error(_("Do not directly access maintenance.php")), __FILE__, __LINE__);
 }
 
-if ($conf['compress_pages']) {
-    ob_start('ob_gzhandler');
-}
+Horde::compressOutput();
 
 /* Load the module specific maintenance class now. */
 include_once $registry->getParam('fileroot', $module) . '/lib/Maintenance/' . $module . '.php';
@@ -58,5 +56,3 @@ foreach ($tasks as $pref) {
 /* Print bottom of confirmation page. */
 require HORDE_TEMPLATES . '/maintenance/confirm_bottom.inc';
 require HORDE_TEMPLATES . '/common-footer.inc';
-
-?>
