@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: horde/menu.php,v 2.14.2.10 2002/04/14 15:26:40 jan Exp $
+ * $Horde: horde/menu.php,v 2.14.2.13 2004/03/26 22:43:21 jan Exp $
  *
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -31,7 +31,7 @@ $moduletext = '';
  * will be other stuff here)
  */
 foreach ($registry->applications as $service => $params) {
-    if ($params['show']) {
+    if ($params['status'] == 'active') {
         if (!$opener) {
             $moduletext .= Menu::createItem(Horde::url($params['webroot'] . '/' . (isset($params['initial_page']) ? $params['initial_page'] : '')),
                                             gettext($params['name']), $params['icon'], '', 'horde_main');
