@@ -6,7 +6,7 @@
  * For usage information call it like:
  * ./translation.php help
  *
- * $Horde: horde/po/translation.php,v 1.27.2.6 2003/02/19 22:56:39 jan Exp $
+ * $Horde: horde/po/translation.php,v 1.27.2.11 2004/03/30 17:43:47 jan Exp $
  */
 
 function writeln($text = '', $pre = false)
@@ -159,7 +159,9 @@ function check_binaries()
 
     print(_("PHP support in xgettext: "));
     $sh = $GLOBALS['xgettext'] . ' --help';
+    putenv('LANG=en');
     $xget_help = `$sh`;
+    putenv('LANG=' . $GLOBALS['language']);
     if (strstr($xget_help, 'PHP')) {
         writeln(green(_("Yes")));
         $GLOBALS['php_support'] = true;
@@ -198,7 +200,7 @@ function xtract()
             $sh = 'cd ' . HORDE_BASE . '; ' .
                   $GLOBALS['xgettext'] . ' --language=' . $language . ' --keyword=_ --sort-output --copyright-holder="Horde Project" -o ' . $dirs[$i] . '/po/' . $apps[$i] . '.pot' .
                   ' `find . -maxdepth 1 -name \'*\\.php\'`' .
-                  ' `find admin lib templates util -name \'*\\.php\' -o -name \'*\\.inc\' -type f`' .
+                  ' `find admin lib templates util -name \'*\\.php\' -o -name \'*\\.inc\' -o -name \'*\\.js\' -type f`' .
                   ' `find config -name \'*\\.dist\' -type f`';
             if (@file_exists(HORDE_BASE . '/po/translation.php')) {
                 $sh .= ' po/translation.php';
@@ -214,7 +216,7 @@ function xtract()
         } else {
             $sh = 'cd ' . $dirs[$i] . '; ' .
                   $GLOBALS['xgettext'] . ' --language=' . $language . ' --keyword=_ --sort-output --copyright-holder="Horde Project" -o ' . $dirs[$i] . '/po/' . $apps[$i] . '.pot' .
-                  ' `find . -name \'*\\.php\' -or -name \'*\\.inc\' -type f | grep -v /config/`' .
+                  ' `find . -name \'*\\.php\' -o -name \'*\\.inc\' -o -name \'*\\.js\' -type f | grep -v /config/`' .
                   ' `find config -name \'*\\.dist\' -type f`' .
                   ($debug ? '' : ' 2> /dev/null');
             if ($debug || $test) {
@@ -225,7 +227,7 @@ function xtract()
         }
         writeln(green(_("done")));
     }
-    chdir($curdir);
+    chdir(trim($curdir));
 }
 
 function merge()
@@ -1135,7 +1137,7 @@ if ($debug) {
 $applist = str_replace(HORDE_BASE . '/', '', str_replace(HORDE_BASE . "\n", '', $dirlist));
 $apps = explode("\n", $applist);
 sort($apps);
-$apps = array_merge('horde', $apps);
+$apps = array_merge(array('horde'), $apps);
 writeln(wordwrap(sprintf(_("Found applications: %s"), implode(', ', $apps))));
 writeln();
 
