@@ -1,12 +1,12 @@
 <?php
 /*
- * $Horde: horde/prefs.php,v 2.1.2.2 2002/04/17 22:58:26 jan Exp $
+ * $Horde: horde/prefs.php,v 2.1.2.8 2004/03/26 22:43:21 jan Exp $
  *
- * Copyright 1999-2002 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2002 Jon Parise <jon@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (LGPL).  If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
 /**
@@ -18,6 +18,15 @@ function groupIsEditable($group)
     return PrefsUI::groupIsEditable($group);
 }
 
+function prefs_callback()
+{
+    global $prefs, $js_onLoad;
+
+    if ($prefs->isDirty('menu_view')) {
+        $js_onLoad = 'if (window.parent.frames.horde_menu) window.parent.frames.horde_menu.location.reload();';
+    }
+}
+
 define('HORDE_BASE', dirname(__FILE__));
 require_once HORDE_BASE . '/lib/base.php';
 require_once HORDE_BASE . '/lib/PrefsUI.php';
@@ -28,6 +37,8 @@ if (!Auth::getAuth()) {
     exit;
 }
 
+$js_onLoad = null;
+
 /* See if we have a preferences group set. */
 $group = Horde::getFormData('group');
 
@@ -36,14 +47,20 @@ if (PrefsUI::handleForm($group)) {
     include HORDE_BASE . '/config/prefs.php';
 }
 
-if ($conf['compress_pages']) {
-    ob_start('ob_gzhandler');
+Horde::compressOutput();
+if (!$prefs->isLocked('initial_application')) {
+    $initial_application_options = array();
+    $apps = $registry->listApps();
+    foreach ($apps as $app) {
+        $initial_application_options[$app] = $registry->getParam('name', $app);
+    }
 }
 
+
+
 $title = _("User Options");
-$js_onLoad = null;
 require HORDE_TEMPLATES . '/common-header.inc';
-$notification->notify();
+require HORDE_BASE . '/navbar.php';
 
 /* Assign variables for select lists. */
 if (!$prefs->isLocked('timezone')) {
@@ -55,5 +72,3 @@ PrefsUI::generateUI($group);
 
 $registry->shutdown();
 require HORDE_TEMPLATES . '/common-footer.inc';
-
-?>
