@@ -1,10 +1,10 @@
 <?php
 /**
- * $Horde: horde/test.php,v 1.44.2.21 2003/04/22 18:23:30 slusarz Exp $
+ * $Horde: horde/test.php,v 1.44.2.24 2004/03/26 22:43:21 jan Exp $
  *
- * Copyright 2002-2003 Brent J. Nordquist <bjn@horde.org>
- * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2003 Jon Parise <jon@horde.org>
+ * Copyright 2002-2004 Brent J. Nordquist <bjn@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -177,7 +177,7 @@ $domxml = extension_loaded('domxml');
 $magic_quotes_runtime = !get_magic_quotes_runtime();
 $file_uploads = ini_get('file_uploads');
 $safe_mode = !ini_get('safe_mode');
-$trans_sid = !ini_get('session.trans_sid');
+$trans_sid = !ini_get('session.use_trans_sid');
 
 /* PEAR */
 $pear = true;
@@ -191,7 +191,6 @@ $unkerr = '';
 set_error_handler('testErrorHandler');
 include 'PEAR.php';
 include 'Mail/RFC822.php';
-include 'Mail/mimeDecode.php';
 include 'Log.php';
 include 'DB.php';
 include 'Net/Socket.php';
